Crate probl_number

Crate probl_number 

One integer type with inline small values and shared, canonical large values. The hard size ceiling bounds parsing and individual allocations even before the runtime has a work budget. Hosts can impose a smaller runtime ceiling.

Structs

Integer

Enums

IntError

Constants

MAX_INTEGER_BITS
MAX_INTEGER_DIGITS